@@ -3,7 +3,7 @@
 ### OPEN SOURCE LICENSE - GNU AFFERO PUBLIC LICENSE Version 3.0 #######
 #
 #    Net::FullAuto AWS Installer Dashboard
-#    Copyright (C) 2000-2016  Brian M. Kelly
+#    Copyright (C) 2000-2017  Brian M. Kelly
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as
@@ -22,7 +22,7 @@
 #######################################################################
 
 use Wx::Perl::Packager;
-use Wx;
+use Wx qw(wxOK wxICON_INFORMATION);
 use Cwd;
 our $begin_cwd=cwd();
 chdir "$ENV{PAR_TEMP}/inc" if -e "$ENV{PAR_TEMP}/inc";
@@ -245,7 +245,7 @@ sub SplitterWindow {
    $rightbottom->{righttop}=$righttop;
    $rightbottom->DragAcceptFiles(1);
    $rightbottom->SetBackgroundColour(Wx::Colour->new(128,128,128));
-   my $fp1 = '';my $fp2='';
+   my $fp1='';my $fp2='';my $fp3='';
    unless ($pem_file && $ip_txt) {
      my $pem_f=($full_pem)?$full_pem:'';
      $fp1 = Wx::FilePickerCtrl->new( $rightbottom, -1, $pem_f,
@@ -267,6 +267,16 @@ sub SplitterWindow {
      $fp2->Enable(0) if $csv_f;
      $rightbottom->{fp2}=$fp2;
      EVT_FILEPICKER_CHANGED( $rightbottom, $fp2, \&on_change );
+     $fp3 = Wx::FilePickerCtrl->new( $rightbottom, -1, $csv_f,
+                "Find and Select Private FullAuto Instruction ".
+                "Set",
+                "PM files (*.pm)|*.pm|All files|*.*",
+                [117, 158], [303,-1],wxFLP_USE_TEXTCTRL); #[30,45] 312 size
+     $fp3->SetPath("Optional Private Instruction Set");
+     $fp3->Show(1);
+     $fp3->Enable(1); #if $csv_f;
+     $rightbottom->{fp3}=$fp3;
+     EVT_FILEPICKER_CHANGED( $rightbottom, $fp3, \&on_change );
 
      my $button1=wxPerl::Button->new(
          $rightbottom,
@@ -339,6 +349,7 @@ sub SplitterWindow {
         $firstpaint=1;
      }
      $self->{firstpaint}=$firstpaint;
+     $chk=76;
      my $button4=wxPerl::Button->new(
         $rightbottom,
         "Cleanup",
@@ -375,7 +386,7 @@ sub SplitterWindow {
    $chk=99 if !exists $rightbottom->{firstpaint}
                           && $pem_file && $ip_txt;
    $export_putty_chkbox=Wx::CheckBox->new($rightbottom,-1,'',
-                          [118,$chk-83],[-1,-1],wxTRANSPARENT_WINDOW);
+                          [226,$chk-87],[-1,-1],wxTRANSPARENT_WINDOW); # 118 $chk-83
    $export_putty_chkbox->SetBackgroundColour(Wx::Colour->new(77,77,77));
    $rightbottom->{epcb}=$export_putty_chkbox;
    EVT_CHECKBOX( $rightbottom, $export_putty_chkbox,
@@ -460,7 +471,7 @@ sub on_paint {
     $self->{firstpaint}=$firstpaint;
     $dc->SetTextForeground(Wx::Colour->newRGB(192,192,192));
     $dc->DrawText('Launch New FullAuto Server',460,$chk);
-    $dc->DrawText('Export PuTTY',139,$chk-83);
+    $dc->DrawText('Export PuTTY',244,$chk-87); # 139 $chk-83
 
 }
 
@@ -522,6 +533,7 @@ sub evt_process_exit {
       Wx::LaunchDefaultBrowser($webapp_url,wxBROWSER_NEW_WINDOW);
       $self->{bb}->Enable(1);
       $self->{cleanup}->Enable(1);
+      $self->{fp3}->Enable(1);
     } 
     if ((!(exists $self->{shifted_cmds}) && !(exists $self->{webapp})) ||
          (!($set_shifted_flag) && !($webapp_flag))) {
@@ -529,6 +541,7 @@ sub evt_process_exit {
          $self->{dashboard}->SetBackgroundColour(Wx::Colour->new(32,161,35));
          $self->{statbm}->SetBitmap($self->{presshere});
          $self->{bb}->Enable(1);
+         $self->{fp3}->Enable(1);
          $self->{cleanup}->Enable(1);
          $self->{key}->Enable(1);
          $self->{credentials}->Enable(1);
@@ -549,6 +562,7 @@ sub fullauto_button {
    $self->{ipbox}->Enable(0);
    $self->{fp1}->Enable(0);
    $self->{fp2}->Enable(0);
+   $self->{fp3}->Enable(0);
    $self->{dashboard}->SetBackgroundColour(Wx::Colour->new(248,115,17));
    $self->{statbm}->SetBitmap($self->{underway});
    $self->{nscb}->SetValue(0);
@@ -595,6 +609,16 @@ sub fullauto_button {
       Wx::ExecuteCommand("puttycfg $iptext",wxEXEC_SYNC)
    }
    EVT_WXP_PROCESS_STREAM_EXIT($self, \&evt_process_exit);
+   my $pis=$self->{fp3}->GetPath();
+   if ($pis=~/\.pm$/) {
+      if (exists $ENV{PAR_TEMP} && (-e "$ENV{PAR_TEMP}/inc")) {
+         copy "$pis", "$ENV{PAR_TEMP}/inc";
+      } else {
+         copy "$pis", cwd();
+      }
+   } else {
+      $pis='';
+   }
    unless ((-e "saved.txt") || (-e "ip.txt")) {
       my $ver=`ver`;
       $ver=~s/^.*(Version.*)$/$1/s;
@@ -604,11 +628,12 @@ sub fullauto_button {
       unless (-e "$keybasename.ppk") {
          $self->{cleanup}->Enable(0);
          Wx::ExecuteCommand("puttykey \"$keybasename\" $path $ver",wxEXEC_SYNC);
+         sleep 1;
       }
       if (exists $ENV{PAR_TEMP} && (-e "$ENV{PAR_TEMP}/inc")) {
          copy "$path/$keybasename.ppk", "$ENV{PAR_TEMP}/inc";
       } else {
-         copy "$path/$keybasename.ppk", cwd();
+         copy "$path\\$keybasename.ppk", cwd();
       }
       unlink "$path/$keybasename.ppk";
       my ($rcode,$stdout,$stderr)=('','','');
@@ -621,7 +646,6 @@ sub fullauto_button {
          my $message="Fatal Error: $stderr";
          my $dialog=Wx::MessageDialog->new(
             $self,$message,$title,wxOK|wxICON_EXCLAMATION);
-         $dialog->SetOKLabels("FullAuto Setup will Exit");
          my $choice=$dialog->ShowModal(); 
          return;
       }
@@ -641,11 +665,18 @@ sub fullauto_button {
    } else {
       copy "cmds_saved.template", "cmds.txt";
    }
+   if ($pis) {
+      $pis=~s/^.*\\(.*)$/$1/;
+      my $c="pscp.exe -batch -v -i \"$keybasename.ppk\" ".
+            "$pis ec2-user\@$i:/home/ec2-user";
+      Wx::Shell($c);
+   }
    open(FH,"+<cmds.txt");
    my $out='';my $k=$keybasename.'.pem';
    while(my $line=<FH>) {
       $line=~s/_p_/$k/eg;
       $line=~s/_c_/$self->{tagged}/eg;
+      $line=~s/_i_/$pis/eg;
       $out.=$line;
    }
    seek(FH,0,0);
@@ -695,6 +726,7 @@ sub on_change {
       $self->{dashboard}->SetBackgroundColour(Wx::Colour->new(32,161,35));
       $self->{bb}->SetBitmap($self->{bmp});
       $self->{bb}->Enable(1);
+      $self->{fp3}->Enable(1);
       $self->{cleanup}->Enable(1);
    } elsif ($text=$self->{fp1}->GetPath()) {
       $self->{statbm}->SetBitmap($self->{notready});
@@ -1256,7 +1288,7 @@ sub on_about {
    $info->SetVersion( '0.01' );
    $info->SetDescription( 'FullAuto Automates EVERYTHING AWS Installer Dashboard' );
    $info->SetCopyright(
-      "(c) 2000-2016 Brian Kelly <Brian.Kelly\@FullAutoSoftware.net>" );
+      "(c) 2000-2017 Brian Kelly <Brian.Kelly\@FullAutoSoftware.net>" );
    $info->SetWebSite(
       'http://www.FullAutoSoftware.net', 'The FullAuto web site' );
    $info->AddDeveloper( 'Brian Kelly <Brian.Kelly@FullAutoSoftware.net>' );
