@@ -37,7 +37,8 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(new_user_amazon run_aws_cmd get_aws_security_id
                  launch_server $configure_aws1 $pem_file $credpath
-                 $aws_configure $aws connect_shell cmd_raw);
+                 $aws_configure $aws connect_shell cmd_raw
+		 fullauto_builddir);
 our $pem_file='';
 our $credpath='.';
 our $aws={};
@@ -287,6 +288,26 @@ sub add_and_tag_server {
 
 }
 
+sub fullauto_builddir {
+
+   my $handle=$_[0];
+   my $sudo=$_[1]||'';
+   my ($stdout,$stderr)=('','');
+   ($stdout,$stderr)=$handle->cmd("${sudo}perl -e \'use CPAN;".
+      "CPAN::HandleConfig-\>load;print \$CPAN::Config-\>{build_dir}\'");
+   my $builddir=$stdout;
+   my $fa_ver=$Net::FullAuto::VERSION;
+   ($stdout,$stderr)=$handle->cmd(
+      "${sudo}ls -1t $builddir | grep Net-FullAuto-$fa_ver");
+   my @lstmp=split /\n/,$stdout;
+   my @ls_tmp=();
+   foreach my $line (@lstmp) {
+      unshift @ls_tmp, $line if $line!~/\.yml$/;
+   }
+   return $builddir.'/'.$ls_tmp[0];
+
+}
+
 sub launch_server {
 
    my $server_type=$_[0];
